import { IWorkspaceDashboardsService, IGetDashboardOptions, IGetScheduledMailOptions, SupportedDashboardReferenceTypes, IDashboardWithReferences, IDashboardReferences, IWidgetAlertCount, SupportedWidgetReferenceTypes, IWidgetReferences, IExportResult, IGetDashboardPluginOptions, IDashboardsQuery, IRawExportCustomOverrides } from "@gooddata/sdk-backend-spi";
import { IFilter, ObjRef, FilterContextItem, IFilterContextDefinition, IWidgetAlert, IWidgetAlertDefinition, IWidget, IScheduledMail, IScheduledMailDefinition, IDashboard, IDashboardDefinition, IListedDashboard, IDashboardPlugin, IDashboardPluginDefinition, IDashboardPermissions, IExistingDashboard, IDateFilter, IDashboardFilterView, IDashboardAttributeFilterConfig, IExecutionDefinition, IFilterContext } from "@gooddata/sdk-model";
/**
 * @alpha
 */
export declare abstract class DecoratedWorkspaceDashboardsService implements IWorkspaceDashboardsService {
    protected decorated: IWorkspaceDashboardsService;
    workspace: string;
    protected constructor(decorated: IWorkspaceDashboardsService, workspace: string);
    getDashboards(options?: IGetDashboardOptions): Promise<IListedDashboard[]>;
    getDashboardsQuery(): IDashboardsQuery;
    getDashboard(ref: ObjRef, filterContextRef?: ObjRef, options?: IGetDashboardOptions): Promise<IDashboard>;
    getDashboardWithReferences(ref: ObjRef, filterContextRef?: ObjRef, options?: IGetDashboardOptions, types?: SupportedDashboardReferenceTypes[]): Promise<IDashboardWithReferences>;
    getFilterContextByExportId: (exportId: string, type: "visual" | "slides" | undefined) => Promise<{
        filterContext?: IFilterContext;
        title?: string;
        hideWidgetTitles?: boolean;
    } | null>;
    getDashboardReferencedObjects(dashboard: IDashboard, types?: SupportedDashboardReferenceTypes[]): Promise<IDashboardReferences>;
    createDashboard(dashboard: IDashboardDefinition): Promise<IDashboard>;
    updateDashboard(dashboard: IDashboard, updatedDashboard: IDashboardDefinition): Promise<IDashboard>;
    deleteDashboard(ref: ObjRef): Promise<void>;
    exportDashboardToPdf(ref: ObjRef, filters?: FilterContextItem[]): Promise<IExportResult>;
    exportDashboardToPresentation(ref: ObjRef, format: "PPTX" | "PDF", filters?: FilterContextItem[], options?: {
        widgetIds?: ObjRef[];
        filename?: string;
    }): Promise<IExportResult>;
    exportDashboardToTabular(ref: ObjRef): Promise<IExportResult>;
    exportDashboardToCSVRaw(definition: IExecutionDefinition, fileName: string, customOverrides?: IRawExportCustomOverrides): Promise<IExportResult>;
    createScheduledMail(scheduledMail: IScheduledMailDefinition, exportFilterContext?: IFilterContextDefinition): Promise<IScheduledMail>;
    updateScheduledMail(ref: ObjRef, scheduledMailDefinition: IScheduledMailDefinition, filterContextRef?: ObjRef): Promise<void>;
    deleteScheduledMail(ref: ObjRef): Promise<void>;
    getScheduledMailsForDashboard(ref: ObjRef, options?: IGetScheduledMailOptions): Promise<IScheduledMail[]>;
    getScheduledMailsCountForDashboard(ref: ObjRef): Promise<number>;
    getAllWidgetAlertsForCurrentUser(): Promise<IWidgetAlert[]>;
    getDashboardWidgetAlertsForCurrentUser(ref: ObjRef): Promise<IWidgetAlert[]>;
    getWidgetAlertsCountForWidgets(refs: ObjRef[]): Promise<IWidgetAlertCount[]>;
    createWidgetAlert(alert: IWidgetAlertDefinition): Promise<IWidgetAlert>;
    updateWidgetAlert(alert: IWidgetAlert | IWidgetAlertDefinition): Promise<IWidgetAlert>;
    deleteWidgetAlert(ref: ObjRef): Promise<void>;
    deleteWidgetAlerts(refs: ObjRef[]): Promise<void>;
    getWidgetReferencedObjects(widget: IWidget, types?: SupportedWidgetReferenceTypes[]): Promise<IWidgetReferences>;
    getResolvedFiltersForWidget(widget: IWidget, filters: IFilter[], attributeFilterConfigs: IDashboardAttributeFilterConfig[]): Promise<IFilter[]>;
    getResolvedFiltersForWidgetWithMultipleDateFilters(widget: IWidget, commonDateFilters: IDateFilter[], otherFilters: IFilter[], attributeFilterConfigs: IDashboardAttributeFilterConfig[]): Promise<IFilter[]>;
    getDashboardPlugins(options?: IGetDashboardPluginOptions): Promise<IDashboardPlugin[]>;
    getDashboardPlugin(ref: ObjRef, options?: IGetDashboardPluginOptions): Promise<IDashboardPlugin>;
    createDashboardPlugin(plugin: IDashboardPluginDefinition): Promise<IDashboardPlugin>;
    deleteDashboardPlugin(ref: ObjRef): Promise<void>;
    getDashboardPermissions(ref: ObjRef): Promise<IDashboardPermissions>;
    validateDashboardsExistence(dashboardRefs: ObjRef[]): Promise<IExistingDashboard[]>;
    getFilterViewsForCurrentUser(dashboardRef: ObjRef): Promise<IDashboardFilterView[]>;
    createFilterView(filterView: IDashboardFilterView): Promise<IDashboardFilterView>;
    deleteFilterView(ref: ObjRef): Promise<void>;
    setFilterViewAsDefault(ref: ObjRef, isDefault: boolean): Promise<void>;
}
//# sourceMappingURL=dashboards.d.ts.map